Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMarc Khouzam2012-03-24 17:38:42 +0000
committerMarc Khouzam2012-03-24 17:38:42 +0000
commit5d924afa08ea3c1be7a3302d4ee89bdeb7f1dd2d (patch)
tree0b1f5bdc8f85c102da012b37af01c116785d21aa /dsf-gdb/org.eclipse.cdt.dsf.gdb
parent2199fee857a3ca76ab3f999d10a9514041ed0778 (diff)
downloadorg.eclipse.cdt-5d924afa08ea3c1be7a3302d4ee89bdeb7f1dd2d.tar.gz
org.eclipse.cdt-5d924afa08ea3c1be7a3302d4ee89bdeb7f1dd2d.tar.xz
org.eclipse.cdt-5d924afa08ea3c1be7a3302d4ee89bdeb7f1dd2d.zip
Bug 375256: Use the wording: 'normal' instead of 'slow' for tracepoints
Diffstat (limited to 'dsf-gdb/org.eclipse.cdt.dsf.gdb')
-rw-r--r--dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/IGDBLaunchConfigurationConstants.java10
-rw-r--r--dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/service/GDBBreakpoints_7_2.java32
-rw-r--r--dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/mi/service/command/output/MIBreakpoint.java6
3 files changed, 24 insertions, 24 deletions
diff --git a/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/mi/service/command/output/MIBreakpoint.java b/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/mi/service/command/output/MIBreakpoint.java
index 6c67e986119..310901feb1c 100644
--- a/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/mi/service/command/output/MIBreakpoint.java
+++ b/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/mi/service/command/output/MIBreakpoint.java
@@ -88,7 +88,7 @@ public class MIBreakpoint {
boolean isHdw = false;
// Indicate if we are dealing with a tracepoint.
- // (if its a fast or slow tracepoint can be known through the 'type' field)
+ // (if its a fast or normal tracepoint can be known through the 'type' field)
boolean isTpt = false;
/** See {@link #isCatchpoint()} */
@@ -343,8 +343,8 @@ public class MIBreakpoint {
/**
* Return whether this breakpoint is actually a tracepoint.
- * This method will return true for both fast and slow tracepoints.
- * To know of fast vs slow tracepoint use {@link getType()} and look
+ * This method will return true for both fast and normal tracepoints.
+ * To know of fast vs normal tracepoint use {@link getType()} and look
* for "tracepoint" or "fast tracepoint"
*
* @since 3.0

Back to the top
diff --git a/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/IGDBLaunchConfigurationConstants.java b/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/IGDBLaunchConfigurationConstants.java
index 9807ec2f5ec..0f1cf56d63b 100644
--- a/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/IGDBLaunchConfigurationConstants.java
+++ b/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/IGDBLaunchConfigurationConstants.java
@@ -185,10 +185,10 @@ public class IGDBLaunchConfigurationConstants {
/**
* Possible attribute value for the key is ATTR_DEBUGGER_TRACEPOINT_MODE.
* Indicates that only slow tracepoints should be used.
* @since 4.1
*/
- public static final String DEBUGGER_TRACEPOINT_SLOW_ONLY = "TP_SLOW_ONLY"; //$NON-NLS-1$
+ public static final String DEBUGGER_TRACEPOINT_NORMAL_ONLY = "TP_NORMAL_ONLY"; //$NON-NLS-1$
/**
* Possible attribute value for the key is ATTR_DEBUGGER_TRACEPOINT_MODE.
@@ -199,17 +199,17 @@ public class IGDBLaunchConfigurationConstants {
/**
* Possible attribute value for the key is ATTR_DEBUGGER_TRACEPOINT_MODE.
* Indicates that slow tracepoints should be used whenever a fast tracepoint
* cannot be inserted.
* @since 4.1
*/
- public static final String DEBUGGER_TRACEPOINT_FAST_THEN_SLOW = "TP_FAST_THEN_SLOW"; //$NON-NLS-1$
+ public static final String DEBUGGER_TRACEPOINT_FAST_THEN_NORMAL = "TP_FAST_THEN_NORMAL"; //$NON-NLS-1$
/**
* Default attribute value for the key is ATTR_DEBUGGER_TRACEPOINT_MODE.
* @since 4.1
*/
- public static final String DEBUGGER_TRACEPOINT_MODE_DEFAULT = DEBUGGER_TRACEPOINT_SLOW_ONLY;
+ public static final String DEBUGGER_TRACEPOINT_MODE_DEFAULT = DEBUGGER_TRACEPOINT_NORMAL_ONLY;
/**
* The default value of DebugPlugin.ATTR_PROCESS_FACTORY_ID.
@@ -185,10 +185,10 @@ public class IGDBLaunchConfigurationConstants {
/**
* Possible attribute value for the key is ATTR_DEBUGGER_TRACEPOINT_MODE.
- * Indicates that only slow tracepoints should be used.
+ * Indicates that only normal tracepoints should be used.
* @since 4.1
*/
@@ -199,17 +199,17 @@ public class IGDBLaunchConfigurationConstants {
/**
* Possible attribute value for the key is ATTR_DEBUGGER_TRACEPOINT_MODE.
- * Indicates that slow tracepoints should be used whenever a fast tracepoint
+ * Indicates that normal tracepoints should be used whenever a fast tracepoint
* cannot be inserted.
* @since 4.1
diff --git a/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/service/GDBBreakpoints_7_2.java b/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/service/GDBBreakpoints_7_2.java
index 1ed6a835f44..088c3591b20 100644
--- a/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/service/GDBBreakpoints_7_2.java
+++ b/dsf-gdb/org.eclipse.cdt.dsf.gdb/src/org/eclipse/cdt/dsf/gdb/service/GDBBreakpoints_7_2.java
@@ -37,7 +37,7 @@ import org.eclipse.debug.core.ILaunch;
/**
* Breakpoint service for GDB 7.2.
* It support MI for tracepoints.
* It also support for fast vs slow tracepoints.
*
* @since 4.1
*/
@@ -45,9 +45,9 @@ public class GDBBreakpoints_7_2 extends GDBBreakpoints_7_0
{
private IMICommandControl fConnection;
- private enum TracepointMode { FAST_THEN_SLOW, FAST_ONLY, SLOW_ONLY };
+ private enum TracepointMode { FAST_THEN_NORMAL, FAST_ONLY, NORMAL_ONLY };
- private TracepointMode fTracepointMode = TracepointMode.SLOW_ONLY;
+ private TracepointMode fTracepointMode = TracepointMode.NORMAL_ONLY;
public GDBBreakpoints_7_2(DsfSession session) {
super(session);
@@ -100,13 +100,13 @@ public class GDBBreakpoints_7_2 extends GDBBreakpoints_7_0
if (tpMode.equals(IGDBLaunchConfigurationConstants.DEBUGGER_TRACEPOINT_FAST_ONLY)) {
fTracepointMode = TracepointMode.FAST_ONLY;
- } else if (tpMode.equals(IGDBLaunchConfigurationConstants.DEBUGGER_TRACEPOINT_SLOW_ONLY)) {
- fTracepointMode = TracepointMode.SLOW_ONLY;
- } else if (tpMode.equals(IGDBLaunchConfigurationConstants.DEBUGGER_TRACEPOINT_FAST_THEN_SLOW)) {
- fTracepointMode = TracepointMode.FAST_THEN_SLOW;
+ } else if (tpMode.equals(IGDBLaunchConfigurationConstants.DEBUGGER_TRACEPOINT_NORMAL_ONLY)) {
+ fTracepointMode = TracepointMode.NORMAL_ONLY;
+ } else if (tpMode.equals(IGDBLaunchConfigurationConstants.DEBUGGER_TRACEPOINT_FAST_THEN_NORMAL)) {
+ fTracepointMode = TracepointMode.FAST_THEN_NORMAL;
} else {
assert false : "Invalid tracepoint mode: " + tpMode; //$NON-NLS-1$
- fTracepointMode = TracepointMode.SLOW_ONLY;
+ fTracepointMode = TracepointMode.NORMAL_ONLY;
}
}
@@ -178,14 +178,14 @@ public class GDBBreakpoints_7_2 extends GDBBreakpoints_7_0
}
/**
* Add a tracepoint using MI. We have three settings:
* 1- set only a fast tracepoint but if it fails, set a slow tracepoint
* 2- only set a fast tracepoint even if it fails
* 3- only set a slow tracepoint even if a fast tracepoint could have been used
*/
@Override
protected void addTracepoint(final IBreakpointsTargetDMContext context, final Map<String, Object> attributes, final DataRequestMonitor<IBreakpointDMContext> drm) {
- // Unless we should only set slow tracepoints, we try to set a fast tracepoint.
- boolean isFastTracepoint = fTracepointMode != TracepointMode.SLOW_ONLY;
+ // Unless we should only set normal tracepoints, we try to set a fast tracepoint.
+ boolean isFastTracepoint = fTracepointMode != TracepointMode.NORMAL_ONLY;
sendTracepointCommand(context, attributes, isFastTracepoint, new ImmediateDataRequestMonitor<IBreakpointDMContext>(drm) {
@Override
@@ -197,12 +197,12 @@ public class GDBBreakpoints_7_2 extends GDBBreakpoints_7_0
@Override
protected void handleError() {
// Tracepoint failed to be set.
- if (fTracepointMode == TracepointMode.FAST_THEN_SLOW) {
- // In this case, we failed to set a fast tracepoint, but we should try to set a slow one.
+ if (fTracepointMode == TracepointMode.FAST_THEN_NORMAL) {
+ // In this case, we failed to set a fast tracepoint, but we should try to set a normal one.
sendTracepointCommand(context, attributes, false, drm);
} else {
// We either failed to set a fast tracepoint and we should not try to set a slow one,
// or we failed to set a slow one. Either way, we are done.
drm.setStatus(getStatus());
drm.done();
}
@@ -37,7 +37,7 @@ import org.eclipse.debug.core.ILaunch;
* Breakpoint service for GDB 7.2.
* It support MI for tracepoints.
- * It also support for fast vs slow tracepoints.
+ * It also support for fast vs normal tracepoints.
*
* @since 4.1
@@ -178,14 +178,14 @@ public class GDBBreakpoints_7_2 extends GDBBreakpoints_7_0
/**
* Add a tracepoint using MI. We have three settings:
- * 1- set only a fast tracepoint but if it fails, set a slow tracepoint
+ * 1- set only a fast tracepoint but if it fails, set a normal tracepoint
* 2- only set a fast tracepoint even if it fails
@@ -178,14 +178,14 @@ public class GDBBreakpoints_7_2 extends GDBBreakpoints_7_0
* 2- only set a fast tracepoint even if it fails
- * 3- only set a slow tracepoint even if a fast tracepoint could have been used
+ * 3- only set a normal tracepoint even if a fast tracepoint could have been used
*/
@@ -197,12 +197,12 @@ public class GDBBreakpoints_7_2 extends GDBBreakpoints_7_0
sendTracepointCommand(context, attributes, false, drm);
} else {
- // We either failed to set a fast tracepoint and we should not try to set a slow one,
- // or we failed to set a slow one. Either way, we are done.
+ // We either failed to set a fast tracepoint and we should not try to set a normal one,
+ // or we failed to set a normal one. Either way, we are done.
drm.setStatus(getStatus());
drm.done();